==> haskell-newtype-generics-0.5.3-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: newtype-generics
version: 0.5.3
id: newtype-generics-0.5.3-C1J8Ev6YDaSA8p4tsDmLzo
key: newtype-generics-0.5.3-C1J8Ev6YDaSA8p4tsDmLzo
license: BSD-3-Clause
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.
category: Control
abi: 244ba36fce78e50081be7eaa8e7e5cdb
exposed: True
exposed-modules:
    Control.Newtype Control.Newtype.Generics
import-dirs: /usr/lib/ghc-8.6.5/site-local/newtype-generics-0.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/newtype-generics-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/newtype-generics-0.5.3
hs-libraries: HSnewtype-generics-0.5.3-C1J8Ev6YDaSA8p4tsDmLzo
depends:
    base-4.12.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock
haddock-html: /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-newtype-generics-0.5.3-46-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: newtype-generics
version: 0.5.3
id: newtype-generics-0.5.3-Jecdq9R9nnA2pAUVJ1uBr2
key: newtype-generics-0.5.3-Jecdq9R9nnA2pAUVJ1uBr2
license: BSD-3-Clause
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.
category: Control
abi: 904937e3b4a5d17526f73454c4f7b8ff
exposed: True
exposed-modules:
    Control.Newtype Control.Newtype.Generics
import-dirs: /usr/lib/ghc-8.6.5/site-local/newtype-generics-0.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/newtype-generics-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/newtype-generics-0.5.3
hs-libraries: HSnewtype-generics-0.5.3-Jecdq9R9nnA2pAUVJ1uBr2
depends:
    base-4.12.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock
haddock-html: /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
